/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { AbstractControl } from '@angular/forms';

export function ValidateDate(control: AbstractControl) {
  if(control.value !== null) {
    let val: string;
    // if they used the ngDatePicker, the value returned is an object rather than a string
    if (control.value && typeof control.value == "object" && control.value.hasOwnProperty('year')) {
      val = control.value.year + '-' + (control.value.month < 10 ? '0' : '') + control.value.month + '-' + (control.value.day < 10 ? '0' : '') + control.value.day;
    } else {
      val = control.value;
    }
    let matches = val.match(/^(\d{4})-(\d{2})-(\d{2})$/);
    if (matches == null) {
      return {invalidDate: true};
    }
  }
  return null;
}
