"""add stage updating to all workflows

Revision ID: e61671602ed0
Revises: db9a82bc2020
Create Date: 2023-03-17 09:16:49.694517

"""
from pathlib import Path

from alembic import op


# revision identifiers, used by Alembic.
revision = "e61671602ed0"
down_revision = "cccb662bd181"
branch_labels = None
depends_on = None

old_condor_imports = """nraorsync://$(SBIN_PATH)/pycapo,"""
new_condor_imports = """nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/update_stage,"""

old_lustre_chirp = """should_transfer_files = NO"""
new_lustre_chirp = """should_transfer_files = NO
+WantIOProxy = True"""

# list of currently live workflows
wf_list = [
    "std_calibration",
    "std_cms_imaging",
    "vlass_calibration",
    "vlass_coarse",
    "vlass_quicklook",
    "vlass_seci",
    "pims_split",
]


def set_content(wf_name: str, filename: str) -> str:
    return (Path.cwd() / "versions" / "templates" / wf_name / filename).read_text()


def upgrade():
    # add update_stage to condor imports, if applicable
    for wf in wf_list:
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content = replace(convert_from(content, 'utf8'), E'{old_condor_imports}', E'{new_condor_imports}')::bytea
            WHERE workflow_name = '{wf}' AND filename like '%.condor'
            """
        )

    # enable chirp functionality for all workflows, when not already present
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), E'{old_lustre_chirp}', E'{new_lustre_chirp}')::bytea
        WHERE filename like '%.condor'
        """
    )

    # update std_calibration
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_calibration", "fetch_2.8.1.txt")}'
        WHERE filename = 'std_calibration_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_calibration", "envoy_2.8.1.txt")}'
        WHERE filename = 'std_calibration_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_calibration", "convey_2.8.1.txt")}'
        WHERE filename = 'std_calibration_convey.sh'
        """
    )

    # update std_cms_imaging
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_cms_imaging", "envoy_2.8.1.txt")}'
        WHERE filename = 'std_cms_imaging_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_cms_imaging", "convey_2.8.1.txt")}'
        WHERE filename = 'std_cms_imaging_convey.sh'
        """
    )

    # update vlass_calibration
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_calibration", "fetch_2.8.1.txt")}'
        WHERE filename = 'vlass_calibration_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_calibration", "envoy_2.8.1.txt")}'
        WHERE filename = 'vlass_calibration_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_calibration", "convey_2.8.1.txt")}'
        WHERE filename = 'vlass_calibration_convey.sh'
        """
    )

    # update vlass_coarse
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_coarse", "fetch_2.8.1.txt")}'
        WHERE filename = 'vlass_coarse_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_coarse", "envoy_2.8.1.txt")}'
        WHERE filename = 'vlass_coarse_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_coarse", "post_2.8.1.txt")}'
        WHERE filename = 'vlass_coarse_post.sh'
        """
    )

    # update vlass_quicklook
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_quicklook", "fetch_2.8.1.txt")}'
        WHERE filename = 'vlass_ql_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_quicklook", "envoy_2.8.1.txt")}'
        WHERE filename = 'vlass_ql_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_quicklook", "post_2.8.1.txt")}'
        WHERE filename = 'vlass_ql_post.sh'
        """
    )

    # update vlass_seci
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_seci", "fetch_2.8.1.txt")}'
        WHERE filename = 'vlass_seci_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_seci", "envoy_2.8.1.txt")}'
        WHERE filename = 'vlass_seci_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_seci", "post_2.8.1.txt")}'
        WHERE filename = 'vlass_seci_post.sh'
        """
    )

    # update pims_split
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("pims_split", "restore_2.8.1.txt")}'
        WHERE filename = 'restore.sh'
        """
    )
    # because the encoding has issues otherwise, sigh.
    conn = op.get_bind()
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'split.sh'
        """,
        set_content("pims_split", "split_2.8.1.txt").encode(),
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'write_finished_file.sh'
        """,
        set_content("pims_split", "finish_2.8.1.txt").encode(),
    )


def downgrade():
    # undo update_stage to condor imports, if applicable
    for wf in wf_list:
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content = replace(convert_from(content, 'utf8'), E'{new_condor_imports}', E'{old_condor_imports}')::bytea
            WHERE workflow_name = '{wf}' AND filename like '%.condor'
            """
        )

    # undo chirp functionality for all workflows, when not already present
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = replace(convert_from(content, 'utf8'), E'{new_lustre_chirp}', E'{old_lustre_chirp}')::bytea
        WHERE filename like '%.condor'
        """
    )

    # undo std_calibration
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_calibration", "lustre_only_fetch_sh_2.7.txt")}'
        WHERE filename = 'std_calibration_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_calibration", "lustre_only_envoy_sh_2.7.txt")}'
        WHERE filename = 'std_calibration_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_calibration", "lustre_only_convey_sh_2.7.txt")}'
        WHERE filename = 'std_calibration_convey.sh'
        """
    )

    # undo std_cms_imaging
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_cms_imaging", "lustre_only_envoy_sh_2.7.txt")}'
        WHERE filename = 'std_cms_imaging_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("std_cms_imaging", "lustre_only_convey_sh_2.7.txt")}'
        WHERE filename = 'std_cms_imaging_convey.sh'
        """
    )

    # undo vlass_calibration
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_calibration", "lustre_only_fetch_sh_2.7.txt")}'
        WHERE filename = 'vlass_calibration_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_calibration", "lustre_only_envoy_sh_2.7.txt")}'
        WHERE filename = 'vlass_calibration_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_calibration", "lustre_only_convey_sh_2.7.txt")}'
        WHERE filename = 'vlass_calibration_convey.sh'
        """
    )

    # update vlass_coarse
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_coarse", "fetch_2.8.0.txt")}'
        WHERE filename = 'vlass_coarse_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_coarse", "envoy_2.8.0.txt")}'
        WHERE filename = 'vlass_coarse_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_coarse", "post_2.8.0.txt")}'
        WHERE filename = 'vlass_coarse_post.sh'
        """
    )

    # undo vlass_quicklook
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_quicklook", "fetch_2.8.0.txt")}'
        WHERE filename = 'vlass_ql_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_quicklook", "envoy_2.8.0.txt")}'
        WHERE filename = 'vlass_ql_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_quicklook", "post_2.8.0.txt")}'
        WHERE filename = 'vlass_ql_post.sh'
        """
    )

    # update vlass_seci
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_seci", "fetch_2.8.0.txt")}'
        WHERE filename = 'vlass_seci_fetch.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_seci", "envoy_2.8.0.txt")}'
        WHERE filename = 'vlass_seci_envoy.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("vlass_seci", "post_2.8.0.txt")}'
        WHERE filename = 'vlass_seci_post.sh'
        """
    )

    # update pims_split
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{set_content("pims_split", "lustre_only_restore_sh_2.7.txt")}'
        WHERE filename = 'restore.sh'
        """
    )
    # because the encoding has issues otherwise, sigh.
    conn = op.get_bind()
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'split.sh'
        """,
        set_content("pims_split", "split_2.8.0.txt").encode(),
    )
    conn.execute(
        f"""
        UPDATE workflow_templates
        SET content = %s
        WHERE filename = 'write_finished_file.sh'
        """,
        set_content("pims_split", "finish_2.8.0.txt").encode(),
    )
